@@ -36,42 +36,42 @@ from .type_defs import (
     AnomalyMonitorTypeDef,
     AnomalySubscriptionTypeDef,
     CostCategoryRuleTypeDef,
-    CreateAnomalyMonitorResponseTypeDef,
-    CreateAnomalySubscriptionResponseTypeDef,
-    CreateCostCategoryDefinitionResponseTypeDef,
+    CreateAnomalyMonitorResponseResponseTypeDef,
+    CreateAnomalySubscriptionResponseResponseTypeDef,
+    CreateCostCategoryDefinitionResponseResponseTypeDef,
     DateIntervalTypeDef,
-    DeleteCostCategoryDefinitionResponseTypeDef,
-    DescribeCostCategoryDefinitionResponseTypeDef,
+    DeleteCostCategoryDefinitionResponseResponseTypeDef,
+    DescribeCostCategoryDefinitionResponseResponseTypeDef,
     ExpressionTypeDef,
-    GetAnomaliesResponseTypeDef,
-    GetAnomalyMonitorsResponseTypeDef,
-    GetAnomalySubscriptionsResponseTypeDef,
-    GetCostAndUsageResponseTypeDef,
-    GetCostAndUsageWithResourcesResponseTypeDef,
-    GetCostCategoriesResponseTypeDef,
-    GetCostForecastResponseTypeDef,
-    GetDimensionValuesResponseTypeDef,
-    GetReservationCoverageResponseTypeDef,
-    GetReservationPurchaseRecommendationResponseTypeDef,
-    GetReservationUtilizationResponseTypeDef,
-    GetRightsizingRecommendationResponseTypeDef,
-    GetSavingsPlansCoverageResponseTypeDef,
-    GetSavingsPlansPurchaseRecommendationResponseTypeDef,
-    GetSavingsPlansUtilizationDetailsResponseTypeDef,
-    GetSavingsPlansUtilizationResponseTypeDef,
-    GetTagsResponseTypeDef,
-    GetUsageForecastResponseTypeDef,
+    GetAnomaliesResponseResponseTypeDef,
+    GetAnomalyMonitorsResponseResponseTypeDef,
+    GetAnomalySubscriptionsResponseResponseTypeDef,
+    GetCostAndUsageResponseResponseTypeDef,
+    GetCostAndUsageWithResourcesResponseResponseTypeDef,
+    GetCostCategoriesResponseResponseTypeDef,
+    GetCostForecastResponseResponseTypeDef,
+    GetDimensionValuesResponseResponseTypeDef,
+    GetReservationCoverageResponseResponseTypeDef,
+    GetReservationPurchaseRecommendationResponseResponseTypeDef,
+    GetReservationUtilizationResponseResponseTypeDef,
+    GetRightsizingRecommendationResponseResponseTypeDef,
+    GetSavingsPlansCoverageResponseResponseTypeDef,
+    GetSavingsPlansPurchaseRecommendationResponseResponseTypeDef,
+    GetSavingsPlansUtilizationDetailsResponseResponseTypeDef,
+    GetSavingsPlansUtilizationResponseResponseTypeDef,
+    GetTagsResponseResponseTypeDef,
+    GetUsageForecastResponseResponseTypeDef,
     GroupDefinitionTypeDef,
-    ListCostCategoryDefinitionsResponseTypeDef,
-    ProvideAnomalyFeedbackResponseTypeDef,
+    ListCostCategoryDefinitionsResponseResponseTypeDef,
+    ProvideAnomalyFeedbackResponseResponseTypeDef,
     RightsizingRecommendationConfigurationTypeDef,
     ServiceSpecificationTypeDef,
     SortDefinitionTypeDef,
     SubscriberTypeDef,
     TotalImpactFilterTypeDef,
-    UpdateAnomalyMonitorResponseTypeDef,
-    UpdateAnomalySubscriptionResponseTypeDef,
-    UpdateCostCategoryDefinitionResponseTypeDef,
+    UpdateAnomalyMonitorResponseResponseTypeDef,
+    UpdateAnomalySubscriptionResponseResponseTypeDef,
+    UpdateCostCategoryDefinitionResponseResponseTypeDef,
 )
 
 if sys.version_info >= (3, 8):
@@ -107,7 +107,7 @@ class Exceptions:
 
 class CostExplorerClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ce.html#CostExplorer.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html)
     """
 
@@ -116,23 +116,30 @@ class CostExplorerClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ce.html#CostExplorer.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#can_paginate)
         """
 
     def create_anomaly_monitor(
         self, *, AnomalyMonitor: "AnomalyMonitorTypeDef"
-    ) -> CreateAnomalyMonitorResponseTypeDef:
+    ) -> CreateAnomalyMonitorResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ce.html#CostExplorer.Client.create_anomaly_monitor)
+        Creates a new cost anomaly detection monitor with the requested type and monitor
+        specification.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.create_anomaly_monitor)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#create_anomaly_monitor)
         """
 
     def create_anomaly_subscription(
         self, *, AnomalySubscription: "AnomalySubscriptionTypeDef"
-    ) -> CreateAnomalySubscriptionResponseTypeDef:
+    ) -> CreateAnomalySubscriptionResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ce.html#CostExplorer.Client.create_anomaly_subscription)
+        Adds a subscription to a cost anomaly detection monitor.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.create_anomaly_subscription)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#create_anomaly_subscription)
         """
 
@@ -143,37 +150,48 @@ class CostExplorerClient:
         RuleVersion: Literal["CostCategoryExpression.v1"],
         Rules: List["CostCategoryRuleTypeDef"],
         DefaultValue: str = None
-    ) -> CreateCostCategoryDefinitionResponseTypeDef:
+    ) -> CreateCostCategoryDefinitionResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ce.html#CostExplorer.Client.create_cost_category_definition)
+        Creates a new Cost Category with the requested name and rules.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.create_cost_category_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#create_cost_category_definition)
         """
 
     def delete_anomaly_monitor(self, *, MonitorArn: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ce.html#CostExplorer.Client.delete_anomaly_monitor)
+        Deletes a cost anomaly monitor.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.delete_anomaly_monitor)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#delete_anomaly_monitor)
         """
 
     def delete_anomaly_subscription(self, *, SubscriptionArn: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ce.html#CostExplorer.Client.delete_anomaly_subscription)
+        Deletes a cost anomaly subscription.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.delete_anomaly_subscription)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#delete_anomaly_subscription)
         """
 
     def delete_cost_category_definition(
         self, *, CostCategoryArn: str
-    ) -> DeleteCostCategoryDefinitionResponseTypeDef:
+    ) -> DeleteCostCategoryDefinitionResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ce.html#CostExplorer.Client.delete_cost_category_definition)
+        Deletes a Cost Category.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.delete_cost_category_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#delete_cost_category_definition)
         """
 
     def describe_cost_category_definition(
         self, *, CostCategoryArn: str, EffectiveOn: str = None
-    ) -> DescribeCostCategoryDefinitionResponseTypeDef:
+    ) -> DescribeCostCategoryDefinitionResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ce.html#CostExplorer.Client.describe_cost_category_definition)
+        Returns the name, ARN, rules, definition, and effective dates of a Cost Category
+        that's defined in the account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.describe_cost_category_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#describe_cost_category_definition)
         """
 
@@ -185,30 +203,37 @@ class CostExplorerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ce.html#CostExplorer.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#generate_presigned_url)
         """
 
     def get_anomalies(
         self,
         *,
-        DateInterval: AnomalyDateIntervalTypeDef,
+        DateInterval: "AnomalyDateIntervalTypeDef",
         MonitorArn: str = None,
         Feedback: AnomalyFeedbackTypeType = None,
-        TotalImpact: TotalImpactFilterTypeDef = None,
+        TotalImpact: "TotalImpactFilterTypeDef" = None,
         NextPageToken: str = None,
         MaxResults: int = None
-    ) -> GetAnomaliesResponseTypeDef:
+    ) -> GetAnomaliesResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ce.html#CostExplorer.Client.get_anomalies)
+        Retrieves all of the cost anomalies detected on your account, during the time
+        period specified by the `DateInterval` object.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_anomalies)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_anomalies)
         """
 
     def get_anomaly_monitors(
         self, *, MonitorArnList: List[str] = None, NextPageToken: str = None, MaxResults: int = None
-    ) -> GetAnomalyMonitorsResponseTypeDef:
+    ) -> GetAnomalyMonitorsResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ce.html#CostExplorer.Client.get_anomaly_monitors)
+        Retrieves the cost anomaly monitor definitions for your account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_anomaly_monitors)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_anomaly_monitors)
         """
 
@@ -219,9 +244,11 @@ class CostExplorerClient:
         MonitorArn: str = None,
         NextPageToken: str = None,
         MaxResults: int = None
-    ) -> GetAnomalySubscriptionsResponseTypeDef:
+    ) -> GetAnomalySubscriptionsResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ce.html#CostExplorer.Client.get_anomaly_subscriptions)
+        Retrieves the cost anomaly subscription objects for your account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_anomaly_subscriptions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_anomaly_subscriptions)
         """
 
@@ -234,9 +261,11 @@ class CostExplorerClient:
         Filter: "ExpressionTypeDef" = None,
         GroupBy: List["GroupDefinitionTypeDef"] = None,
         NextPageToken: str = None
-    ) -> GetCostAndUsageResponseTypeDef:
+    ) -> GetCostAndUsageResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage)
+        Retrieves cost and usage metrics for your account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_cost_and_usage)
         """
 
@@ -249,9 +278,11 @@ class CostExplorerClient:
         Metrics: List[str] = None,
         GroupBy: List["GroupDefinitionTypeDef"] = None,
         NextPageToken: str = None
-    ) -> GetCostAndUsageWithResourcesResponseTypeDef:
+    ) -> GetCostAndUsageWithResourcesResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage_with_resources)
+        Retrieves cost and usage metrics with resources for your account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage_with_resources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_cost_and_usage_with_resources)
         """
 
@@ -262,12 +293,14 @@ class CostExplorerClient:
         SearchString: str = None,
         CostCategoryName: str = None,
         Filter: "ExpressionTypeDef" = None,
-        SortBy: List[SortDefinitionTypeDef] = None,
+        SortBy: List["SortDefinitionTypeDef"] = None,
         MaxResults: int = None,
         NextPageToken: str = None
-    ) -> GetCostCategoriesResponseTypeDef:
+    ) -> GetCostCategoriesResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ce.html#CostExplorer.Client.get_cost_categories)
+        Retrieves an array of Cost Category names and values incurred cost.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_cost_categories)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_cost_categories)
         """
 
@@ -279,9 +312,12 @@ class CostExplorerClient:
         Granularity: GranularityType,
         Filter: "ExpressionTypeDef" = None,
         PredictionIntervalLevel: int = None
-    ) -> GetCostForecastResponseTypeDef:
+    ) -> GetCostForecastResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ce.html#CostExplorer.Client.get_cost_forecast)
+        Retrieves a forecast for how much Amazon Web Services predicts that you will
+        spend over the forecast time period that you select, based on your past costs.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_cost_forecast)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_cost_forecast)
         """
 
@@ -293,12 +329,15 @@ class CostExplorerClient:
         SearchString: str = None,
         Context: ContextType = None,
         Filter: "ExpressionTypeDef" = None,
-        SortBy: List[SortDefinitionTypeDef] = None,
+        SortBy: List["SortDefinitionTypeDef"] = None,
         MaxResults: int = None,
         NextPageToken: str = None
-    ) -> GetDimensionValuesResponseTypeDef:
+    ) -> GetDimensionValuesResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ce.html#CostExplorer.Client.get_dimension_values)
+        Retrieves all available filter values for a specified filter over a period of
+        time.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_dimension_values)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_dimension_values)
         """
 
@@ -311,11 +350,13 @@ class CostExplorerClient:
         Filter: "ExpressionTypeDef" = None,
         Metrics: List[str] = None,
         NextPageToken: str = None,
-        SortBy: SortDefinitionTypeDef = None,
+        SortBy: "SortDefinitionTypeDef" = None,
         MaxResults: int = None
-    ) -> GetReservationCoverageResponseTypeDef:
+    ) -> GetReservationCoverageResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ce.html#CostExplorer.Client.get_reservation_coverage)
+        Retrieves the reservation coverage for your account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_reservation_coverage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_reservation_coverage)
         """
 
@@ -332,9 +373,11 @@ class CostExplorerClient:
         ServiceSpecification: "ServiceSpecificationTypeDef" = None,
         PageSize: int = None,
         NextPageToken: str = None
-    ) -> GetReservationPurchaseRecommendationResponseTypeDef:
+    ) -> GetReservationPurchaseRecommendationResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ce.html#CostExplorer.Client.get_reservation_purchase_recommendation)
+        Gets recommendations for which reservations to purchase.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_reservation_purchase_recommendation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_reservation_purchase_recommendation)
         """
 
@@ -345,12 +388,14 @@ class CostExplorerClient:
         GroupBy: List["GroupDefinitionTypeDef"] = None,
         Granularity: GranularityType = None,
         Filter: "ExpressionTypeDef" = None,
-        SortBy: SortDefinitionTypeDef = None,
+        SortBy: "SortDefinitionTypeDef" = None,
         NextPageToken: str = None,
         MaxResults: int = None
-    ) -> GetReservationUtilizationResponseTypeDef:
+    ) -> GetReservationUtilizationResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ce.html#CostExplorer.Client.get_reservation_utilization)
+        Retrieves the reservation utilization for your account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_reservation_utilization)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_reservation_utilization)
         """
 
@@ -362,9 +407,12 @@ class CostExplorerClient:
         Configuration: "RightsizingRecommendationConfigurationTypeDef" = None,
         PageSize: int = None,
         NextPageToken: str = None
-    ) -> GetRightsizingRecommendationResponseTypeDef:
+    ) -> GetRightsizingRecommendationResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ce.html#CostExplorer.Client.get_rightsizing_recommendation)
+        Creates recommendations that help you save cost by identifying idle and
+        underutilized Amazon EC2 instances.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_rightsizing_recommendation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_rightsizing_recommendation)
         """
 
@@ -378,10 +426,12 @@ class CostExplorerClient:
         Metrics: List[str] = None,
         NextToken: str = None,
         MaxResults: int = None,
-        SortBy: SortDefinitionTypeDef = None
-    ) -> GetSavingsPlansCoverageResponseTypeDef:
+        SortBy: "SortDefinitionTypeDef" = None
+    ) -> GetSavingsPlansCoverageResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ce.html#CostExplorer.Client.get_savings_plans_coverage)
+        Retrieves the Savings Plans covered for your account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_savings_plans_coverage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_savings_plans_coverage)
         """
 
@@ -396,9 +446,12 @@ class CostExplorerClient:
         NextPageToken: str = None,
         PageSize: int = None,
         Filter: "ExpressionTypeDef" = None
-    ) -> GetSavingsPlansPurchaseRecommendationResponseTypeDef:
+    ) -> GetSavingsPlansPurchaseRecommendationResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ce.html#CostExplorer.Client.get_savings_plans_purchase_recommendation)
+        Retrieves your request parameters, Savings Plan Recommendations Summary and
+        Details.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_savings_plans_purchase_recommendation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_savings_plans_purchase_recommendation)
         """
 
@@ -408,10 +461,13 @@ class CostExplorerClient:
         TimePeriod: "DateIntervalTypeDef",
         Granularity: GranularityType = None,
         Filter: "ExpressionTypeDef" = None,
-        SortBy: SortDefinitionTypeDef = None
-    ) -> GetSavingsPlansUtilizationResponseTypeDef:
+        SortBy: "SortDefinitionTypeDef" = None
+    ) -> GetSavingsPlansUtilizationResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization)
+        Retrieves the Savings Plans utilization for your account across date ranges with
+        daily or monthly granularity.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_savings_plans_utilization)
         """
 
@@ -423,10 +479,13 @@ class CostExplorerClient:
         DataType: List[SavingsPlansDataTypeType] = None,
         NextToken: str = None,
         MaxResults: int = None,
-        SortBy: SortDefinitionTypeDef = None
-    ) -> GetSavingsPlansUtilizationDetailsResponseTypeDef:
+        SortBy: "SortDefinitionTypeDef" = None
+    ) -> GetSavingsPlansUtilizationDetailsResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization_details)
+        Retrieves attribute data along with aggregate utilization and savings data for a
+        given time period.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization_details)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_savings_plans_utilization_details)
         """
 
@@ -437,12 +496,14 @@ class CostExplorerClient:
         SearchString: str = None,
         TagKey: str = None,
         Filter: "ExpressionTypeDef" = None,
-        SortBy: List[SortDefinitionTypeDef] = None,
+        SortBy: List["SortDefinitionTypeDef"] = None,
         MaxResults: int = None,
         NextPageToken: str = None
-    ) -> GetTagsResponseTypeDef:
+    ) -> GetTagsResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ce.html#CostExplorer.Client.get_tags)
+        Queries for available tag keys and tag values for a specified period.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_tags)
         """
 
@@ -454,33 +515,43 @@ class CostExplorerClient:
         Granularity: GranularityType,
         Filter: "ExpressionTypeDef" = None,
         PredictionIntervalLevel: int = None
-    ) -> GetUsageForecastResponseTypeDef:
+    ) -> GetUsageForecastResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ce.html#CostExplorer.Client.get_usage_forecast)
+        Retrieves a forecast for how much Amazon Web Services predicts that you will use
+        over the forecast time period that you select, based on your past usage.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_usage_forecast)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_usage_forecast)
         """
 
     def list_cost_category_definitions(
         self, *, EffectiveOn: str = None, NextToken: str = None, MaxResults: int = None
-    ) -> ListCostCategoryDefinitionsResponseTypeDef:
+    ) -> ListCostCategoryDefinitionsResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ce.html#CostExplorer.Client.list_cost_category_definitions)
+        Returns the name, ARN, `NumberOfRules` and effective dates of all Cost
+        Categories defined in the account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.list_cost_category_definitions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#list_cost_category_definitions)
         """
 
     def provide_anomaly_feedback(
         self, *, AnomalyId: str, Feedback: AnomalyFeedbackTypeType
-    ) -> ProvideAnomalyFeedbackResponseTypeDef:
+    ) -> ProvideAnomalyFeedbackResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ce.html#CostExplorer.Client.provide_anomaly_feedback)
+        Modifies the feedback property of a given cost anomaly.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.provide_anomaly_feedback)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#provide_anomaly_feedback)
         """
 
     def update_anomaly_monitor(
         self, *, MonitorArn: str, MonitorName: str = None
-    ) -> UpdateAnomalyMonitorResponseTypeDef:
+    ) -> UpdateAnomalyMonitorResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ce.html#CostExplorer.Client.update_anomaly_monitor)
+        Updates an existing cost anomaly monitor.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.update_anomaly_monitor)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#update_anomaly_monitor)
         """
 
@@ -493,9 +564,11 @@ class CostExplorerClient:
         MonitorArnList: List[str] = None,
         Subscribers: List["SubscriberTypeDef"] = None,
         SubscriptionName: str = None
-    ) -> UpdateAnomalySubscriptionResponseTypeDef:
+    ) -> UpdateAnomalySubscriptionResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ce.html#CostExplorer.Client.update_anomaly_subscription)
+        Updates an existing cost anomaly monitor subscription.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.update_anomaly_subscription)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#update_anomaly_subscription)
         """
 
@@ -506,8 +579,10 @@ class CostExplorerClient:
         RuleVersion: Literal["CostCategoryExpression.v1"],
         Rules: List["CostCategoryRuleTypeDef"],
         DefaultValue: str = None
-    ) -> UpdateCostCategoryDefinitionResponseTypeDef:
+    ) -> UpdateCostCategoryDefinitionResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/ce.html#CostExplorer.Client.update_cost_category_definition)
+        Updates an existing Cost Category.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.update_cost_category_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#update_cost_category_definition)
         """
