@@ -18,14 +18,17 @@ from .literals import (
     AccountScopeType,
     AnomalyFeedbackTypeType,
     AnomalySubscriptionFrequencyType,
+    ContextType,
     CostCategoryInheritedValueDimensionNameType,
     CostCategoryRuleTypeType,
     CostCategoryStatusType,
     DimensionType,
     FindingReasonCodeType,
+    GranularityType,
     GroupDefinitionTypeType,
     LookbackPeriodInDaysType,
     MatchOptionType,
+    MetricType,
     MonitorTypeType,
     NumericOperatorType,
     OfferingClassType,
@@ -33,6 +36,7 @@ from .literals import (
     PlatformDifferenceType,
     RecommendationTargetType,
     RightsizingTypeType,
+    SavingsPlansDataTypeType,
     SortOrderType,
     SubscriberStatusType,
     SubscriberTypeType,
@@ -67,13 +71,20 @@ __all__ = (
     "CoverageHoursTypeDef",
     "CoverageNormalizedUnitsTypeDef",
     "CoverageTypeDef",
-    "CreateAnomalyMonitorResponseTypeDef",
-    "CreateAnomalySubscriptionResponseTypeDef",
-    "CreateCostCategoryDefinitionResponseTypeDef",
+    "CreateAnomalyMonitorRequestTypeDef",
+    "CreateAnomalyMonitorResponseResponseTypeDef",
+    "CreateAnomalySubscriptionRequestTypeDef",
+    "CreateAnomalySubscriptionResponseResponseTypeDef",
+    "CreateCostCategoryDefinitionRequestTypeDef",
+    "CreateCostCategoryDefinitionResponseResponseTypeDef",
     "CurrentInstanceTypeDef",
     "DateIntervalTypeDef",
-    "DeleteCostCategoryDefinitionResponseTypeDef",
-    "DescribeCostCategoryDefinitionResponseTypeDef",
+    "DeleteAnomalyMonitorRequestTypeDef",
+    "DeleteAnomalySubscriptionRequestTypeDef",
+    "DeleteCostCategoryDefinitionRequestTypeDef",
+    "DeleteCostCategoryDefinitionResponseResponseTypeDef",
+    "DescribeCostCategoryDefinitionRequestTypeDef",
+    "DescribeCostCategoryDefinitionResponseResponseTypeDef",
     "DimensionValuesTypeDef",
     "DimensionValuesWithAttributesTypeDef",
     "DiskResourceUtilizationTypeDef",
@@ -86,33 +97,53 @@ __all__ = (
     "ElastiCacheInstanceDetailsTypeDef",
     "ExpressionTypeDef",
     "ForecastResultTypeDef",
-    "GetAnomaliesResponseTypeDef",
-    "GetAnomalyMonitorsResponseTypeDef",
-    "GetAnomalySubscriptionsResponseTypeDef",
-    "GetCostAndUsageResponseTypeDef",
-    "GetCostAndUsageWithResourcesResponseTypeDef",
-    "GetCostCategoriesResponseTypeDef",
-    "GetCostForecastResponseTypeDef",
-    "GetDimensionValuesResponseTypeDef",
-    "GetReservationCoverageResponseTypeDef",
-    "GetReservationPurchaseRecommendationResponseTypeDef",
-    "GetReservationUtilizationResponseTypeDef",
-    "GetRightsizingRecommendationResponseTypeDef",
-    "GetSavingsPlansCoverageResponseTypeDef",
-    "GetSavingsPlansPurchaseRecommendationResponseTypeDef",
-    "GetSavingsPlansUtilizationDetailsResponseTypeDef",
-    "GetSavingsPlansUtilizationResponseTypeDef",
-    "GetTagsResponseTypeDef",
-    "GetUsageForecastResponseTypeDef",
+    "GetAnomaliesRequestTypeDef",
+    "GetAnomaliesResponseResponseTypeDef",
+    "GetAnomalyMonitorsRequestTypeDef",
+    "GetAnomalyMonitorsResponseResponseTypeDef",
+    "GetAnomalySubscriptionsRequestTypeDef",
+    "GetAnomalySubscriptionsResponseResponseTypeDef",
+    "GetCostAndUsageRequestTypeDef",
+    "GetCostAndUsageResponseResponseTypeDef",
+    "GetCostAndUsageWithResourcesRequestTypeDef",
+    "GetCostAndUsageWithResourcesResponseResponseTypeDef",
+    "GetCostCategoriesRequestTypeDef",
+    "GetCostCategoriesResponseResponseTypeDef",
+    "GetCostForecastRequestTypeDef",
+    "GetCostForecastResponseResponseTypeDef",
+    "GetDimensionValuesRequestTypeDef",
+    "GetDimensionValuesResponseResponseTypeDef",
+    "GetReservationCoverageRequestTypeDef",
+    "GetReservationCoverageResponseResponseTypeDef",
+    "GetReservationPurchaseRecommendationRequestTypeDef",
+    "GetReservationPurchaseRecommendationResponseResponseTypeDef",
+    "GetReservationUtilizationRequestTypeDef",
+    "GetReservationUtilizationResponseResponseTypeDef",
+    "GetRightsizingRecommendationRequestTypeDef",
+    "GetRightsizingRecommendationResponseResponseTypeDef",
+    "GetSavingsPlansCoverageRequestTypeDef",
+    "GetSavingsPlansCoverageResponseResponseTypeDef",
+    "GetSavingsPlansPurchaseRecommendationRequestTypeDef",
+    "GetSavingsPlansPurchaseRecommendationResponseResponseTypeDef",
+    "GetSavingsPlansUtilizationDetailsRequestTypeDef",
+    "GetSavingsPlansUtilizationDetailsResponseResponseTypeDef",
+    "GetSavingsPlansUtilizationRequestTypeDef",
+    "GetSavingsPlansUtilizationResponseResponseTypeDef",
+    "GetTagsRequestTypeDef",
+    "GetTagsResponseResponseTypeDef",
+    "GetUsageForecastRequestTypeDef",
+    "GetUsageForecastResponseResponseTypeDef",
     "GroupDefinitionTypeDef",
     "GroupTypeDef",
     "ImpactTypeDef",
     "InstanceDetailsTypeDef",
-    "ListCostCategoryDefinitionsResponseTypeDef",
+    "ListCostCategoryDefinitionsRequestTypeDef",
+    "ListCostCategoryDefinitionsResponseResponseTypeDef",
     "MetricValueTypeDef",
     "ModifyRecommendationDetailTypeDef",
     "NetworkResourceUtilizationTypeDef",
-    "ProvideAnomalyFeedbackResponseTypeDef",
+    "ProvideAnomalyFeedbackRequestTypeDef",
+    "ProvideAnomalyFeedbackResponseResponseTypeDef",
     "RDSInstanceDetailsTypeDef",
     "RedshiftInstanceDetailsTypeDef",
     "ReservationAggregatesTypeDef",
@@ -124,6 +155,7 @@ __all__ = (
     "ReservationUtilizationGroupTypeDef",
     "ResourceDetailsTypeDef",
     "ResourceUtilizationTypeDef",
+    "ResponseMetadataTypeDef",
     "ResultByTimeTypeDef",
     "RightsizingRecommendationConfigurationTypeDef",
     "RightsizingRecommendationMetadataTypeDef",
@@ -150,9 +182,12 @@ __all__ = (
     "TargetInstanceTypeDef",
     "TerminateRecommendationDetailTypeDef",
     "TotalImpactFilterTypeDef",
-    "UpdateAnomalyMonitorResponseTypeDef",
-    "UpdateAnomalySubscriptionResponseTypeDef",
-    "UpdateCostCategoryDefinitionResponseTypeDef",
+    "UpdateAnomalyMonitorRequestTypeDef",
+    "UpdateAnomalyMonitorResponseResponseTypeDef",
+    "UpdateAnomalySubscriptionRequestTypeDef",
+    "UpdateAnomalySubscriptionResponseResponseTypeDef",
+    "UpdateCostCategoryDefinitionRequestTypeDef",
+    "UpdateCostCategoryDefinitionResponseResponseTypeDef",
     "UtilizationByTimeTypeDef",
 )
 
@@ -392,27 +427,67 @@ CoverageTypeDef = TypedDict(
     total=False,
 )
 
-CreateAnomalyMonitorResponseTypeDef = TypedDict(
-    "CreateAnomalyMonitorResponseTypeDef",
+CreateAnomalyMonitorRequestTypeDef = TypedDict(
+    "CreateAnomalyMonitorRequestTypeDef",
+    {
+        "AnomalyMonitor": "AnomalyMonitorTypeDef",
+    },
+)
+
+CreateAnomalyMonitorResponseResponseTypeDef = TypedDict(
+    "CreateAnomalyMonitorResponseResponseTypeDef",
     {
         "MonitorArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-CreateAnomalySubscriptionResponseTypeDef = TypedDict(
-    "CreateAnomalySubscriptionResponseTypeDef",
+CreateAnomalySubscriptionRequestTypeDef = TypedDict(
+    "CreateAnomalySubscriptionRequestTypeDef",
+    {
+        "AnomalySubscription": "AnomalySubscriptionTypeDef",
+    },
+)
+
+CreateAnomalySubscriptionResponseResponseTypeDef = TypedDict(
+    "CreateAnomalySubscriptionResponseResponseTypeDef",
     {
         "SubscriptionArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-CreateCostCategoryDefinitionResponseTypeDef = TypedDict(
-    "CreateCostCategoryDefinitionResponseTypeDef",
+_RequiredCreateCostCategoryDefinitionRequestTypeDef = TypedDict(
+    "_RequiredCreateCostCategoryDefinitionRequestTypeDef",
+    {
+        "Name": str,
+        "RuleVersion": Literal["CostCategoryExpression.v1"],
+        "Rules": List["CostCategoryRuleTypeDef"],
+    },
+)
+_OptionalCreateCostCategoryDefinitionRequestTypeDef = TypedDict(
+    "_OptionalCreateCostCategoryDefinitionRequestTypeDef",
+    {
+        "DefaultValue": str,
+    },
+    total=False,
+)
+
+
+class CreateCostCategoryDefinitionRequestTypeDef(
+    _RequiredCreateCostCategoryDefinitionRequestTypeDef,
+    _OptionalCreateCostCategoryDefinitionRequestTypeDef,
+):
+    pass
+
+
+CreateCostCategoryDefinitionResponseResponseTypeDef = TypedDict(
+    "CreateCostCategoryDefinitionResponseResponseTypeDef",
     {
         "CostCategoryArn": str,
         "EffectiveStart": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 CurrentInstanceTypeDef = TypedDict(
@@ -441,21 +516,64 @@ DateIntervalTypeDef = TypedDict(
     },
 )
 
-DeleteCostCategoryDefinitionResponseTypeDef = TypedDict(
-    "DeleteCostCategoryDefinitionResponseTypeDef",
+DeleteAnomalyMonitorRequestTypeDef = TypedDict(
+    "DeleteAnomalyMonitorRequestTypeDef",
+    {
+        "MonitorArn": str,
+    },
+)
+
+DeleteAnomalySubscriptionRequestTypeDef = TypedDict(
+    "DeleteAnomalySubscriptionRequestTypeDef",
+    {
+        "SubscriptionArn": str,
+    },
+)
+
+DeleteCostCategoryDefinitionRequestTypeDef = TypedDict(
+    "DeleteCostCategoryDefinitionRequestTypeDef",
+    {
+        "CostCategoryArn": str,
+    },
+)
+
+DeleteCostCategoryDefinitionResponseResponseTypeDef = TypedDict(
+    "DeleteCostCategoryDefinitionResponseResponseTypeDef",
     {
         "CostCategoryArn": str,
         "EffectiveEnd": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredDescribeCostCategoryDefinitionRequestTypeDef = TypedDict(
+    "_RequiredDescribeCostCategoryDefinitionRequestTypeDef",
+    {
+        "CostCategoryArn": str,
+    },
+)
+_OptionalDescribeCostCategoryDefinitionRequestTypeDef = TypedDict(
+    "_OptionalDescribeCostCategoryDefinitionRequestTypeDef",
+    {
+        "EffectiveOn": str,
     },
     total=False,
 )
 
-DescribeCostCategoryDefinitionResponseTypeDef = TypedDict(
-    "DescribeCostCategoryDefinitionResponseTypeDef",
+
+class DescribeCostCategoryDefinitionRequestTypeDef(
+    _RequiredDescribeCostCategoryDefinitionRequestTypeDef,
+    _OptionalDescribeCostCategoryDefinitionRequestTypeDef,
+):
+    pass
+
+
+DescribeCostCategoryDefinitionResponseResponseTypeDef = TypedDict(
+    "DescribeCostCategoryDefinitionResponseResponseTypeDef",
     {
         "CostCategory": "CostCategoryTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 DimensionValuesTypeDef = TypedDict(
@@ -600,319 +718,622 @@ ForecastResultTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredGetAnomaliesResponseTypeDef = TypedDict(
-    "_RequiredGetAnomaliesResponseTypeDef",
+_RequiredGetAnomaliesRequestTypeDef = TypedDict(
+    "_RequiredGetAnomaliesRequestTypeDef",
+    {
+        "DateInterval": "AnomalyDateIntervalTypeDef",
+    },
+)
+_OptionalGetAnomaliesRequestTypeDef = TypedDict(
+    "_OptionalGetAnomaliesRequestTypeDef",
+    {
+        "MonitorArn": str,
+        "Feedback": AnomalyFeedbackTypeType,
+        "TotalImpact": "TotalImpactFilterTypeDef",
+        "NextPageToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+
+class GetAnomaliesRequestTypeDef(
+    _RequiredGetAnomaliesRequestTypeDef, _OptionalGetAnomaliesRequestTypeDef
+):
+    pass
+
+
+GetAnomaliesResponseResponseTypeDef = TypedDict(
+    "GetAnomaliesResponseResponseTypeDef",
     {
         "Anomalies": List["AnomalyTypeDef"],
+        "NextPageToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
-_OptionalGetAnomaliesResponseTypeDef = TypedDict(
-    "_OptionalGetAnomaliesResponseTypeDef",
+
+GetAnomalyMonitorsRequestTypeDef = TypedDict(
+    "GetAnomalyMonitorsRequestTypeDef",
     {
+        "MonitorArnList": List[str],
         "NextPageToken": str,
+        "MaxResults": int,
     },
     total=False,
 )
 
-
-class GetAnomaliesResponseTypeDef(
-    _RequiredGetAnomaliesResponseTypeDef, _OptionalGetAnomaliesResponseTypeDef
-):
-    pass
-
-
-_RequiredGetAnomalyMonitorsResponseTypeDef = TypedDict(
-    "_RequiredGetAnomalyMonitorsResponseTypeDef",
+GetAnomalyMonitorsResponseResponseTypeDef = TypedDict(
+    "GetAnomalyMonitorsResponseResponseTypeDef",
     {
         "AnomalyMonitors": List["AnomalyMonitorTypeDef"],
+        "NextPageToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
-_OptionalGetAnomalyMonitorsResponseTypeDef = TypedDict(
-    "_OptionalGetAnomalyMonitorsResponseTypeDef",
+
+GetAnomalySubscriptionsRequestTypeDef = TypedDict(
+    "GetAnomalySubscriptionsRequestTypeDef",
     {
+        "SubscriptionArnList": List[str],
+        "MonitorArn": str,
         "NextPageToken": str,
+        "MaxResults": int,
     },
     total=False,
 )
 
-
-class GetAnomalyMonitorsResponseTypeDef(
-    _RequiredGetAnomalyMonitorsResponseTypeDef, _OptionalGetAnomalyMonitorsResponseTypeDef
-):
-    pass
-
-
-_RequiredGetAnomalySubscriptionsResponseTypeDef = TypedDict(
-    "_RequiredGetAnomalySubscriptionsResponseTypeDef",
+GetAnomalySubscriptionsResponseResponseTypeDef = TypedDict(
+    "GetAnomalySubscriptionsResponseResponseTypeDef",
     {
         "AnomalySubscriptions": List["AnomalySubscriptionTypeDef"],
+        "NextPageToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
-_OptionalGetAnomalySubscriptionsResponseTypeDef = TypedDict(
-    "_OptionalGetAnomalySubscriptionsResponseTypeDef",
+
+_RequiredGetCostAndUsageRequestTypeDef = TypedDict(
+    "_RequiredGetCostAndUsageRequestTypeDef",
     {
+        "TimePeriod": "DateIntervalTypeDef",
+        "Granularity": GranularityType,
+        "Metrics": List[str],
+    },
+)
+_OptionalGetCostAndUsageRequestTypeDef = TypedDict(
+    "_OptionalGetCostAndUsageRequestTypeDef",
+    {
+        "Filter": "ExpressionTypeDef",
+        "GroupBy": List["GroupDefinitionTypeDef"],
         "NextPageToken": str,
     },
     total=False,
 )
 
 
-class GetAnomalySubscriptionsResponseTypeDef(
-    _RequiredGetAnomalySubscriptionsResponseTypeDef, _OptionalGetAnomalySubscriptionsResponseTypeDef
+class GetCostAndUsageRequestTypeDef(
+    _RequiredGetCostAndUsageRequestTypeDef, _OptionalGetCostAndUsageRequestTypeDef
 ):
     pass
 
 
-GetCostAndUsageResponseTypeDef = TypedDict(
-    "GetCostAndUsageResponseTypeDef",
+GetCostAndUsageResponseResponseTypeDef = TypedDict(
+    "GetCostAndUsageResponseResponseTypeDef",
     {
         "NextPageToken": str,
         "GroupDefinitions": List["GroupDefinitionTypeDef"],
         "ResultsByTime": List["ResultByTimeTypeDef"],
         "DimensionValueAttributes": List["DimensionValuesWithAttributesTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredGetCostAndUsageWithResourcesRequestTypeDef = TypedDict(
+    "_RequiredGetCostAndUsageWithResourcesRequestTypeDef",
+    {
+        "TimePeriod": "DateIntervalTypeDef",
+        "Granularity": GranularityType,
+        "Filter": "ExpressionTypeDef",
+    },
+)
+_OptionalGetCostAndUsageWithResourcesRequestTypeDef = TypedDict(
+    "_OptionalGetCostAndUsageWithResourcesRequestTypeDef",
+    {
+        "Metrics": List[str],
+        "GroupBy": List["GroupDefinitionTypeDef"],
+        "NextPageToken": str,
     },
     total=False,
 )
 
-GetCostAndUsageWithResourcesResponseTypeDef = TypedDict(
-    "GetCostAndUsageWithResourcesResponseTypeDef",
+
+class GetCostAndUsageWithResourcesRequestTypeDef(
+    _RequiredGetCostAndUsageWithResourcesRequestTypeDef,
+    _OptionalGetCostAndUsageWithResourcesRequestTypeDef,
+):
+    pass
+
+
+GetCostAndUsageWithResourcesResponseResponseTypeDef = TypedDict(
+    "GetCostAndUsageWithResourcesResponseResponseTypeDef",
     {
         "NextPageToken": str,
         "GroupDefinitions": List["GroupDefinitionTypeDef"],
         "ResultsByTime": List["ResultByTimeTypeDef"],
         "DimensionValueAttributes": List["DimensionValuesWithAttributesTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredGetCostCategoriesRequestTypeDef = TypedDict(
+    "_RequiredGetCostCategoriesRequestTypeDef",
+    {
+        "TimePeriod": "DateIntervalTypeDef",
+    },
+)
+_OptionalGetCostCategoriesRequestTypeDef = TypedDict(
+    "_OptionalGetCostCategoriesRequestTypeDef",
+    {
+        "SearchString": str,
+        "CostCategoryName": str,
+        "Filter": "ExpressionTypeDef",
+        "SortBy": List["SortDefinitionTypeDef"],
+        "MaxResults": int,
+        "NextPageToken": str,
     },
     total=False,
 )
 
-_RequiredGetCostCategoriesResponseTypeDef = TypedDict(
-    "_RequiredGetCostCategoriesResponseTypeDef",
-    {
-        "ReturnSize": int,
-        "TotalSize": int,
-    },
-)
-_OptionalGetCostCategoriesResponseTypeDef = TypedDict(
-    "_OptionalGetCostCategoriesResponseTypeDef",
+
+class GetCostCategoriesRequestTypeDef(
+    _RequiredGetCostCategoriesRequestTypeDef, _OptionalGetCostCategoriesRequestTypeDef
+):
+    pass
+
+
+GetCostCategoriesResponseResponseTypeDef = TypedDict(
+    "GetCostCategoriesResponseResponseTypeDef",
     {
         "NextPageToken": str,
         "CostCategoryNames": List[str],
         "CostCategoryValues": List[str],
+        "ReturnSize": int,
+        "TotalSize": int,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredGetCostForecastRequestTypeDef = TypedDict(
+    "_RequiredGetCostForecastRequestTypeDef",
+    {
+        "TimePeriod": "DateIntervalTypeDef",
+        "Metric": MetricType,
+        "Granularity": GranularityType,
+    },
+)
+_OptionalGetCostForecastRequestTypeDef = TypedDict(
+    "_OptionalGetCostForecastRequestTypeDef",
+    {
+        "Filter": "ExpressionTypeDef",
+        "PredictionIntervalLevel": int,
     },
     total=False,
 )
 
 
-class GetCostCategoriesResponseTypeDef(
-    _RequiredGetCostCategoriesResponseTypeDef, _OptionalGetCostCategoriesResponseTypeDef
+class GetCostForecastRequestTypeDef(
+    _RequiredGetCostForecastRequestTypeDef, _OptionalGetCostForecastRequestTypeDef
 ):
     pass
 
 
-GetCostForecastResponseTypeDef = TypedDict(
-    "GetCostForecastResponseTypeDef",
+GetCostForecastResponseResponseTypeDef = TypedDict(
+    "GetCostForecastResponseResponseTypeDef",
     {
         "Total": "MetricValueTypeDef",
         "ForecastResultsByTime": List["ForecastResultTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredGetDimensionValuesRequestTypeDef = TypedDict(
+    "_RequiredGetDimensionValuesRequestTypeDef",
+    {
+        "TimePeriod": "DateIntervalTypeDef",
+        "Dimension": DimensionType,
+    },
+)
+_OptionalGetDimensionValuesRequestTypeDef = TypedDict(
+    "_OptionalGetDimensionValuesRequestTypeDef",
+    {
+        "SearchString": str,
+        "Context": ContextType,
+        "Filter": "ExpressionTypeDef",
+        "SortBy": List["SortDefinitionTypeDef"],
+        "MaxResults": int,
+        "NextPageToken": str,
     },
     total=False,
 )
 
-_RequiredGetDimensionValuesResponseTypeDef = TypedDict(
-    "_RequiredGetDimensionValuesResponseTypeDef",
+
+class GetDimensionValuesRequestTypeDef(
+    _RequiredGetDimensionValuesRequestTypeDef, _OptionalGetDimensionValuesRequestTypeDef
+):
+    pass
+
+
+GetDimensionValuesResponseResponseTypeDef = TypedDict(
+    "GetDimensionValuesResponseResponseTypeDef",
     {
         "DimensionValues": List["DimensionValuesWithAttributesTypeDef"],
         "ReturnSize": int,
         "TotalSize": int,
+        "NextPageToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
-_OptionalGetDimensionValuesResponseTypeDef = TypedDict(
-    "_OptionalGetDimensionValuesResponseTypeDef",
+
+_RequiredGetReservationCoverageRequestTypeDef = TypedDict(
+    "_RequiredGetReservationCoverageRequestTypeDef",
     {
+        "TimePeriod": "DateIntervalTypeDef",
+    },
+)
+_OptionalGetReservationCoverageRequestTypeDef = TypedDict(
+    "_OptionalGetReservationCoverageRequestTypeDef",
+    {
+        "GroupBy": List["GroupDefinitionTypeDef"],
+        "Granularity": GranularityType,
+        "Filter": "ExpressionTypeDef",
+        "Metrics": List[str],
         "NextPageToken": str,
+        "SortBy": "SortDefinitionTypeDef",
+        "MaxResults": int,
     },
     total=False,
 )
 
 
-class GetDimensionValuesResponseTypeDef(
-    _RequiredGetDimensionValuesResponseTypeDef, _OptionalGetDimensionValuesResponseTypeDef
+class GetReservationCoverageRequestTypeDef(
+    _RequiredGetReservationCoverageRequestTypeDef, _OptionalGetReservationCoverageRequestTypeDef
 ):
     pass
 
 
-_RequiredGetReservationCoverageResponseTypeDef = TypedDict(
-    "_RequiredGetReservationCoverageResponseTypeDef",
+GetReservationCoverageResponseResponseTypeDef = TypedDict(
+    "GetReservationCoverageResponseResponseTypeDef",
     {
         "CoveragesByTime": List["CoverageByTimeTypeDef"],
+        "Total": "CoverageTypeDef",
+        "NextPageToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
-_OptionalGetReservationCoverageResponseTypeDef = TypedDict(
-    "_OptionalGetReservationCoverageResponseTypeDef",
+
+_RequiredGetReservationPurchaseRecommendationRequestTypeDef = TypedDict(
+    "_RequiredGetReservationPurchaseRecommendationRequestTypeDef",
     {
-        "Total": "CoverageTypeDef",
+        "Service": str,
+    },
+)
+_OptionalGetReservationPurchaseRecommendationRequestTypeDef = TypedDict(
+    "_OptionalGetReservationPurchaseRecommendationRequestTypeDef",
+    {
+        "AccountId": str,
+        "Filter": "ExpressionTypeDef",
+        "AccountScope": AccountScopeType,
+        "LookbackPeriodInDays": LookbackPeriodInDaysType,
+        "TermInYears": TermInYearsType,
+        "PaymentOption": PaymentOptionType,
+        "ServiceSpecification": "ServiceSpecificationTypeDef",
+        "PageSize": int,
         "NextPageToken": str,
     },
     total=False,
 )
 
 
-class GetReservationCoverageResponseTypeDef(
-    _RequiredGetReservationCoverageResponseTypeDef, _OptionalGetReservationCoverageResponseTypeDef
+class GetReservationPurchaseRecommendationRequestTypeDef(
+    _RequiredGetReservationPurchaseRecommendationRequestTypeDef,
+    _OptionalGetReservationPurchaseRecommendationRequestTypeDef,
 ):
     pass
 
 
-GetReservationPurchaseRecommendationResponseTypeDef = TypedDict(
-    "GetReservationPurchaseRecommendationResponseTypeDef",
+GetReservationPurchaseRecommendationResponseResponseTypeDef = TypedDict(
+    "GetReservationPurchaseRecommendationResponseResponseTypeDef",
     {
         "Metadata": "ReservationPurchaseRecommendationMetadataTypeDef",
         "Recommendations": List["ReservationPurchaseRecommendationTypeDef"],
         "NextPageToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredGetReservationUtilizationRequestTypeDef = TypedDict(
+    "_RequiredGetReservationUtilizationRequestTypeDef",
+    {
+        "TimePeriod": "DateIntervalTypeDef",
+    },
+)
+_OptionalGetReservationUtilizationRequestTypeDef = TypedDict(
+    "_OptionalGetReservationUtilizationRequestTypeDef",
+    {
+        "GroupBy": List["GroupDefinitionTypeDef"],
+        "Granularity": GranularityType,
+        "Filter": "ExpressionTypeDef",
+        "SortBy": "SortDefinitionTypeDef",
+        "NextPageToken": str,
+        "MaxResults": int,
     },
     total=False,
 )
 
-_RequiredGetReservationUtilizationResponseTypeDef = TypedDict(
-    "_RequiredGetReservationUtilizationResponseTypeDef",
+
+class GetReservationUtilizationRequestTypeDef(
+    _RequiredGetReservationUtilizationRequestTypeDef,
+    _OptionalGetReservationUtilizationRequestTypeDef,
+):
+    pass
+
+
+GetReservationUtilizationResponseResponseTypeDef = TypedDict(
+    "GetReservationUtilizationResponseResponseTypeDef",
     {
         "UtilizationsByTime": List["UtilizationByTimeTypeDef"],
+        "Total": "ReservationAggregatesTypeDef",
+        "NextPageToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
-_OptionalGetReservationUtilizationResponseTypeDef = TypedDict(
-    "_OptionalGetReservationUtilizationResponseTypeDef",
+
+_RequiredGetRightsizingRecommendationRequestTypeDef = TypedDict(
+    "_RequiredGetRightsizingRecommendationRequestTypeDef",
     {
-        "Total": "ReservationAggregatesTypeDef",
+        "Service": str,
+    },
+)
+_OptionalGetRightsizingRecommendationRequestTypeDef = TypedDict(
+    "_OptionalGetRightsizingRecommendationRequestTypeDef",
+    {
+        "Filter": "ExpressionTypeDef",
+        "Configuration": "RightsizingRecommendationConfigurationTypeDef",
+        "PageSize": int,
         "NextPageToken": str,
     },
     total=False,
 )
 
 
-class GetReservationUtilizationResponseTypeDef(
-    _RequiredGetReservationUtilizationResponseTypeDef,
-    _OptionalGetReservationUtilizationResponseTypeDef,
+class GetRightsizingRecommendationRequestTypeDef(
+    _RequiredGetRightsizingRecommendationRequestTypeDef,
+    _OptionalGetRightsizingRecommendationRequestTypeDef,
 ):
     pass
 
 
-GetRightsizingRecommendationResponseTypeDef = TypedDict(
-    "GetRightsizingRecommendationResponseTypeDef",
+GetRightsizingRecommendationResponseResponseTypeDef = TypedDict(
+    "GetRightsizingRecommendationResponseResponseTypeDef",
     {
         "Metadata": "RightsizingRecommendationMetadataTypeDef",
         "Summary": "RightsizingRecommendationSummaryTypeDef",
         "RightsizingRecommendations": List["RightsizingRecommendationTypeDef"],
         "NextPageToken": str,
         "Configuration": "RightsizingRecommendationConfigurationTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-_RequiredGetSavingsPlansCoverageResponseTypeDef = TypedDict(
-    "_RequiredGetSavingsPlansCoverageResponseTypeDef",
+_RequiredGetSavingsPlansCoverageRequestTypeDef = TypedDict(
+    "_RequiredGetSavingsPlansCoverageRequestTypeDef",
     {
-        "SavingsPlansCoverages": List["SavingsPlansCoverageTypeDef"],
+        "TimePeriod": "DateIntervalTypeDef",
     },
 )
-_OptionalGetSavingsPlansCoverageResponseTypeDef = TypedDict(
-    "_OptionalGetSavingsPlansCoverageResponseTypeDef",
+_OptionalGetSavingsPlansCoverageRequestTypeDef = TypedDict(
+    "_OptionalGetSavingsPlansCoverageRequestTypeDef",
     {
+        "GroupBy": List["GroupDefinitionTypeDef"],
+        "Granularity": GranularityType,
+        "Filter": "ExpressionTypeDef",
+        "Metrics": List[str],
         "NextToken": str,
+        "MaxResults": int,
+        "SortBy": "SortDefinitionTypeDef",
     },
     total=False,
 )
 
 
-class GetSavingsPlansCoverageResponseTypeDef(
-    _RequiredGetSavingsPlansCoverageResponseTypeDef, _OptionalGetSavingsPlansCoverageResponseTypeDef
+class GetSavingsPlansCoverageRequestTypeDef(
+    _RequiredGetSavingsPlansCoverageRequestTypeDef, _OptionalGetSavingsPlansCoverageRequestTypeDef
 ):
     pass
 
 
-GetSavingsPlansPurchaseRecommendationResponseTypeDef = TypedDict(
-    "GetSavingsPlansPurchaseRecommendationResponseTypeDef",
+GetSavingsPlansCoverageResponseResponseTypeDef = TypedDict(
+    "GetSavingsPlansCoverageResponseResponseTypeDef",
+    {
+        "SavingsPlansCoverages": List["SavingsPlansCoverageTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredGetSavingsPlansPurchaseRecommendationRequestTypeDef = TypedDict(
+    "_RequiredGetSavingsPlansPurchaseRecommendationRequestTypeDef",
+    {
+        "SavingsPlansType": SupportedSavingsPlansTypeType,
+        "TermInYears": TermInYearsType,
+        "PaymentOption": PaymentOptionType,
+        "LookbackPeriodInDays": LookbackPeriodInDaysType,
+    },
+)
+_OptionalGetSavingsPlansPurchaseRecommendationRequestTypeDef = TypedDict(
+    "_OptionalGetSavingsPlansPurchaseRecommendationRequestTypeDef",
+    {
+        "AccountScope": AccountScopeType,
+        "NextPageToken": str,
+        "PageSize": int,
+        "Filter": "ExpressionTypeDef",
+    },
+    total=False,
+)
+
+
+class GetSavingsPlansPurchaseRecommendationRequestTypeDef(
+    _RequiredGetSavingsPlansPurchaseRecommendationRequestTypeDef,
+    _OptionalGetSavingsPlansPurchaseRecommendationRequestTypeDef,
+):
+    pass
+
+
+GetSavingsPlansPurchaseRecommendationResponseResponseTypeDef = TypedDict(
+    "GetSavingsPlansPurchaseRecommendationResponseResponseTypeDef",
     {
         "Metadata": "SavingsPlansPurchaseRecommendationMetadataTypeDef",
         "SavingsPlansPurchaseRecommendation": "SavingsPlansPurchaseRecommendationTypeDef",
         "NextPageToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-_RequiredGetSavingsPlansUtilizationDetailsResponseTypeDef = TypedDict(
-    "_RequiredGetSavingsPlansUtilizationDetailsResponseTypeDef",
+_RequiredGetSavingsPlansUtilizationDetailsRequestTypeDef = TypedDict(
+    "_RequiredGetSavingsPlansUtilizationDetailsRequestTypeDef",
     {
-        "SavingsPlansUtilizationDetails": List["SavingsPlansUtilizationDetailTypeDef"],
         "TimePeriod": "DateIntervalTypeDef",
     },
 )
-_OptionalGetSavingsPlansUtilizationDetailsResponseTypeDef = TypedDict(
-    "_OptionalGetSavingsPlansUtilizationDetailsResponseTypeDef",
+_OptionalGetSavingsPlansUtilizationDetailsRequestTypeDef = TypedDict(
+    "_OptionalGetSavingsPlansUtilizationDetailsRequestTypeDef",
     {
-        "Total": "SavingsPlansUtilizationAggregatesTypeDef",
+        "Filter": "ExpressionTypeDef",
+        "DataType": List[SavingsPlansDataTypeType],
         "NextToken": str,
+        "MaxResults": int,
+        "SortBy": "SortDefinitionTypeDef",
     },
     total=False,
 )
 
 
-class GetSavingsPlansUtilizationDetailsResponseTypeDef(
-    _RequiredGetSavingsPlansUtilizationDetailsResponseTypeDef,
-    _OptionalGetSavingsPlansUtilizationDetailsResponseTypeDef,
+class GetSavingsPlansUtilizationDetailsRequestTypeDef(
+    _RequiredGetSavingsPlansUtilizationDetailsRequestTypeDef,
+    _OptionalGetSavingsPlansUtilizationDetailsRequestTypeDef,
 ):
     pass
 
 
-_RequiredGetSavingsPlansUtilizationResponseTypeDef = TypedDict(
-    "_RequiredGetSavingsPlansUtilizationResponseTypeDef",
+GetSavingsPlansUtilizationDetailsResponseResponseTypeDef = TypedDict(
+    "GetSavingsPlansUtilizationDetailsResponseResponseTypeDef",
     {
+        "SavingsPlansUtilizationDetails": List["SavingsPlansUtilizationDetailTypeDef"],
         "Total": "SavingsPlansUtilizationAggregatesTypeDef",
+        "TimePeriod": "DateIntervalTypeDef",
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
-_OptionalGetSavingsPlansUtilizationResponseTypeDef = TypedDict(
-    "_OptionalGetSavingsPlansUtilizationResponseTypeDef",
+
+_RequiredGetSavingsPlansUtilizationRequestTypeDef = TypedDict(
+    "_RequiredGetSavingsPlansUtilizationRequestTypeDef",
+    {
+        "TimePeriod": "DateIntervalTypeDef",
+    },
+)
+_OptionalGetSavingsPlansUtilizationRequestTypeDef = TypedDict(
+    "_OptionalGetSavingsPlansUtilizationRequestTypeDef",
+    {
+        "Granularity": GranularityType,
+        "Filter": "ExpressionTypeDef",
+        "SortBy": "SortDefinitionTypeDef",
+    },
+    total=False,
+)
+
+
+class GetSavingsPlansUtilizationRequestTypeDef(
+    _RequiredGetSavingsPlansUtilizationRequestTypeDef,
+    _OptionalGetSavingsPlansUtilizationRequestTypeDef,
+):
+    pass
+
+
+GetSavingsPlansUtilizationResponseResponseTypeDef = TypedDict(
+    "GetSavingsPlansUtilizationResponseResponseTypeDef",
     {
         "SavingsPlansUtilizationsByTime": List["SavingsPlansUtilizationByTimeTypeDef"],
-    },
-    total=False,
-)
-
-
-class GetSavingsPlansUtilizationResponseTypeDef(
-    _RequiredGetSavingsPlansUtilizationResponseTypeDef,
-    _OptionalGetSavingsPlansUtilizationResponseTypeDef,
-):
-    pass
-
-
-_RequiredGetTagsResponseTypeDef = TypedDict(
-    "_RequiredGetTagsResponseTypeDef",
-    {
-        "Tags": List[str],
-        "ReturnSize": int,
-        "TotalSize": int,
+        "Total": "SavingsPlansUtilizationAggregatesTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
-_OptionalGetTagsResponseTypeDef = TypedDict(
-    "_OptionalGetTagsResponseTypeDef",
+
+_RequiredGetTagsRequestTypeDef = TypedDict(
+    "_RequiredGetTagsRequestTypeDef",
     {
+        "TimePeriod": "DateIntervalTypeDef",
+    },
+)
+_OptionalGetTagsRequestTypeDef = TypedDict(
+    "_OptionalGetTagsRequestTypeDef",
+    {
+        "SearchString": str,
+        "TagKey": str,
+        "Filter": "ExpressionTypeDef",
+        "SortBy": List["SortDefinitionTypeDef"],
+        "MaxResults": int,
         "NextPageToken": str,
     },
     total=False,
 )
 
 
-class GetTagsResponseTypeDef(_RequiredGetTagsResponseTypeDef, _OptionalGetTagsResponseTypeDef):
+class GetTagsRequestTypeDef(_RequiredGetTagsRequestTypeDef, _OptionalGetTagsRequestTypeDef):
     pass
 
 
-GetUsageForecastResponseTypeDef = TypedDict(
-    "GetUsageForecastResponseTypeDef",
+GetTagsResponseResponseTypeDef = TypedDict(
+    "GetTagsResponseResponseTypeDef",
+    {
+        "NextPageToken": str,
+        "Tags": List[str],
+        "ReturnSize": int,
+        "TotalSize": int,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredGetUsageForecastRequestTypeDef = TypedDict(
+    "_RequiredGetUsageForecastRequestTypeDef",
+    {
+        "TimePeriod": "DateIntervalTypeDef",
+        "Metric": MetricType,
+        "Granularity": GranularityType,
+    },
+)
+_OptionalGetUsageForecastRequestTypeDef = TypedDict(
+    "_OptionalGetUsageForecastRequestTypeDef",
+    {
+        "Filter": "ExpressionTypeDef",
+        "PredictionIntervalLevel": int,
+    },
+    total=False,
+)
+
+
+class GetUsageForecastRequestTypeDef(
+    _RequiredGetUsageForecastRequestTypeDef, _OptionalGetUsageForecastRequestTypeDef
+):
+    pass
+
+
+GetUsageForecastResponseResponseTypeDef = TypedDict(
+    "GetUsageForecastResponseResponseTypeDef",
     {
         "Total": "MetricValueTypeDef",
         "ForecastResultsByTime": List["ForecastResultTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 GroupDefinitionTypeDef = TypedDict(
@@ -964,13 +1385,23 @@ InstanceDetailsTypeDef = TypedDict(
     total=False,
 )
 
-ListCostCategoryDefinitionsResponseTypeDef = TypedDict(
-    "ListCostCategoryDefinitionsResponseTypeDef",
+ListCostCategoryDefinitionsRequestTypeDef = TypedDict(
+    "ListCostCategoryDefinitionsRequestTypeDef",
+    {
+        "EffectiveOn": str,
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+ListCostCategoryDefinitionsResponseResponseTypeDef = TypedDict(
+    "ListCostCategoryDefinitionsResponseResponseTypeDef",
     {
         "CostCategoryReferences": List["CostCategoryReferenceTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 MetricValueTypeDef = TypedDict(
@@ -1001,10 +1432,19 @@ NetworkResourceUtilizationTypeDef = TypedDict(
     total=False,
 )
 
-ProvideAnomalyFeedbackResponseTypeDef = TypedDict(
-    "ProvideAnomalyFeedbackResponseTypeDef",
+ProvideAnomalyFeedbackRequestTypeDef = TypedDict(
+    "ProvideAnomalyFeedbackRequestTypeDef",
     {
         "AnomalyId": str,
+        "Feedback": AnomalyFeedbackTypeType,
+    },
+)
+
+ProvideAnomalyFeedbackResponseResponseTypeDef = TypedDict(
+    "ProvideAnomalyFeedbackResponseResponseTypeDef",
+    {
+        "AnomalyId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
@@ -1155,6 +1595,17 @@ ResourceUtilizationTypeDef = TypedDict(
     total=False,
 )
 
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
+    },
+)
+
 ResultByTimeTypeDef = TypedDict(
     "ResultByTimeTypeDef",
     {
@@ -1498,27 +1949,100 @@ class TotalImpactFilterTypeDef(
     pass
 
 
-UpdateAnomalyMonitorResponseTypeDef = TypedDict(
-    "UpdateAnomalyMonitorResponseTypeDef",
+_RequiredUpdateAnomalyMonitorRequestTypeDef = TypedDict(
+    "_RequiredUpdateAnomalyMonitorRequestTypeDef",
     {
         "MonitorArn": str,
     },
 )
+_OptionalUpdateAnomalyMonitorRequestTypeDef = TypedDict(
+    "_OptionalUpdateAnomalyMonitorRequestTypeDef",
+    {
+        "MonitorName": str,
+    },
+    total=False,
+)
 
-UpdateAnomalySubscriptionResponseTypeDef = TypedDict(
-    "UpdateAnomalySubscriptionResponseTypeDef",
+
+class UpdateAnomalyMonitorRequestTypeDef(
+    _RequiredUpdateAnomalyMonitorRequestTypeDef, _OptionalUpdateAnomalyMonitorRequestTypeDef
+):
+    pass
+
+
+UpdateAnomalyMonitorResponseResponseTypeDef = TypedDict(
+    "UpdateAnomalyMonitorResponseResponseTypeDef",
+    {
+        "MonitorArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredUpdateAnomalySubscriptionRequestTypeDef = TypedDict(
+    "_RequiredUpdateAnomalySubscriptionRequestTypeDef",
     {
         "SubscriptionArn": str,
     },
 )
+_OptionalUpdateAnomalySubscriptionRequestTypeDef = TypedDict(
+    "_OptionalUpdateAnomalySubscriptionRequestTypeDef",
+    {
+        "Threshold": float,
+        "Frequency": AnomalySubscriptionFrequencyType,
+        "MonitorArnList": List[str],
+        "Subscribers": List["SubscriberTypeDef"],
+        "SubscriptionName": str,
+    },
+    total=False,
+)
 
-UpdateCostCategoryDefinitionResponseTypeDef = TypedDict(
-    "UpdateCostCategoryDefinitionResponseTypeDef",
+
+class UpdateAnomalySubscriptionRequestTypeDef(
+    _RequiredUpdateAnomalySubscriptionRequestTypeDef,
+    _OptionalUpdateAnomalySubscriptionRequestTypeDef,
+):
+    pass
+
+
+UpdateAnomalySubscriptionResponseResponseTypeDef = TypedDict(
+    "UpdateAnomalySubscriptionResponseResponseTypeDef",
+    {
+        "SubscriptionArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredUpdateCostCategoryDefinitionRequestTypeDef = TypedDict(
+    "_RequiredUpdateCostCategoryDefinitionRequestTypeDef",
+    {
+        "CostCategoryArn": str,
+        "RuleVersion": Literal["CostCategoryExpression.v1"],
+        "Rules": List["CostCategoryRuleTypeDef"],
+    },
+)
+_OptionalUpdateCostCategoryDefinitionRequestTypeDef = TypedDict(
+    "_OptionalUpdateCostCategoryDefinitionRequestTypeDef",
+    {
+        "DefaultValue": str,
+    },
+    total=False,
+)
+
+
+class UpdateCostCategoryDefinitionRequestTypeDef(
+    _RequiredUpdateCostCategoryDefinitionRequestTypeDef,
+    _OptionalUpdateCostCategoryDefinitionRequestTypeDef,
+):
+    pass
+
+
+UpdateCostCategoryDefinitionResponseResponseTypeDef = TypedDict(
+    "UpdateCostCategoryDefinitionResponseResponseTypeDef",
     {
         "CostCategoryArn": str,
         "EffectiveStart": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 UtilizationByTimeTypeDef = TypedDict(
